pygeai.tests.snippets.chat package
==================================

Submodules
----------

pygeai.tests.snippets.chat.cancel\_request module
-------------------------------------------------

.. automodule:: pygeai.tests.snippets.chat.cancel_request
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.chat.chat\_completion module
--------------------------------------------------

.. automodule:: pygeai.tests.snippets.chat.chat_completion
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.chat.chat\_completion\_1 module
-----------------------------------------------------

.. automodule:: pygeai.tests.snippets.chat.chat_completion_1
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.chat.chat\_completion\_2 module
-----------------------------------------------------

.. automodule:: pygeai.tests.snippets.chat.chat_completion_2
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.chat.chat\_completion\_3 module
-----------------------------------------------------

.. automodule:: pygeai.tests.snippets.chat.chat_completion_3
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.chat.chat\_completion\_4 module
-----------------------------------------------------

.. automodule:: pygeai.tests.snippets.chat.chat_completion_4
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.chat.chat\_completion\_streaming module
-------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.chat.chat_completion_streaming
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.chat.chat\_completion\_with\_reasoning\_effort module
---------------------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.chat.chat_completion_with_reasoning_effort
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.chat.get\_request\_status module
------------------------------------------------------

.. automodule:: pygeai.tests.snippets.chat.get_request_status
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.chat.get\_response module
-----------------------------------------------

.. automodule:: pygeai.tests.snippets.chat.get_response
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.chat.get\_response\_streaming module
----------------------------------------------------------

.. automodule:: pygeai.tests.snippets.chat.get_response_streaming
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.chat.get\_response\_with\_files module
------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.chat.get_response_with_files
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.chat.get\_response\_with\_tools module
------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.chat.get_response_with_tools
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.chat.send\_chat\_request module
-----------------------------------------------------

.. automodule:: pygeai.tests.snippets.chat.send_chat_request
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: pygeai.tests.snippets.chat
   :members:
   :show-inheritance:
   :undoc-members:
